==> ExperimentHubData_1.0.0.tar.gz: ExperimentHubData/R/ExperimentHubMetadata-class.R <==
### =========================================================================
### ExperimentHubMetadata objects
### -------------------------------------------------------------------------
###

setClass("ExperimentHubMetadata",
    contains="HubMetadata",
    representation(
        ExperimentHubRoot="character"
    ),
    prototype = prototype(
        ExperimentHubRoot=NA_character_
    )
)

## -----------------------------------------------------------------------------
## Constructor
## 

makeExperimentHubMetadata <- function(pathToPackage) 
{
    ## Differences from makeAnnotationHubMetadata:
    ## - package put in PreparerClass slot
    ## - Tags are biocViews
    meta <- readMetadataFromCsv(pathToPackage)
    package <- basename(pathToPackage)
    meta$PreparerClass <- package 

    description <- read.dcf(file.path(pathToPackage, "DESCRIPTION"))
    .tags <- strsplit(gsub("\\s", "", description[,"biocViews"]), ",")[[1]]
    lapply(seq_len(nrow(meta)),
        function(x) {
            with(meta[x,], 
                 ExperimentHubMetadata(Title=Title, Description=Description, 
                                       BiocVersion=BiocVersion, Genome=Genome, 
                                       SourceType=SourceType, 
                                       SourceUrl=SourceUrl,
                                       SourceVersion=SourceVersion, 
                                       Species=Species, TaxonomyId=TaxonomyId,
                                       Coordinate_1_based=Coordinate_1_based, 
                                       DataProvider=DataProvider,
                                       Maintainer=Maintainer, 
                                       RDataClass=RDataClass, Tags=.tags, 
                                       RDataDateAdded=RDataDateAdded, 
                                       RDataPath=RDataPath, 
                                       DispatchClass=DispatchClass,
                                       PreparerClass=PreparerClass)) 
        }
    )
}

ExperimentHubMetadata <-
    function(ExperimentHubRoot=NA_character_, 
        BiocVersion=biocVersion(),
        SourceUrl=NA_character_,   ## not necessary because no downloads
        SourceType=NA_character_, 
        SourceVersion=NA_character_, 
        SourceLastModifiedDate=as.POSIXct(NA_character_), 
        SourceMd5=NA_character_, 
        SourceSize=NA_real_,
        DataProvider=NA_character_, 
        Title=NA_character_, 
        Description=NA_character_,
        Maintainer=NA_character_, 
        Species=NA_character_, 
        TaxonomyId=NA_integer_, 
        Genome=NA_character_, 
        Tags=NA_character_,
        RDataClass=NA_character_, 
        RDataDateAdded=as.POSIXct(NA_character_),
        RDataPath=NA_character_,
        Coordinate_1_based=TRUE,
        Notes=NA_character_,
        DispatchClass=NA_character_,
        PreparerClass=NA_character_,
        Location_Prefix='http://s3.amazonaws.com/experimenthub/')
{
    ## FIXME: move these checks to a general validity method
    ##        on HubMetadata that can be reused
    if (is.na(TaxonomyId)) {
        if (!is.na(Species) &&
            requireNamespace("AnnotationHubData", quietly=TRUE))
            TaxonomyId <- GenomeInfoDb:::.taxonomyId(Species)
    }
    ## FIXME: where should these coercions be handled?
    Coordinate_1_based <- as.logical(Coordinate_1_based)
    TaxonomyId <- as.integer(TaxonomyId)
    if(!(isSingleInteger(TaxonomyId) || is.na(TaxonomyId)))
        stop(paste0("ExperimentHubMetdata objects can contain",
                    " only one taxonomy ID or NA"))

    ## FIXME: do we need to handle the case of multiple files per resource?
    if(any(is.na(RDataPath)))
        stop(paste0("ExperimentHubMetdata RDataPath slot cannot contain NAs"))

    if (missing(RDataPath)) { 
        ## Add two characters: one for substr starting AT clipChars
        ## and one for extra slash
        clipChars <- nchar(Location_Prefix) + 2 
        RDataPath <- substr(SourceUrl, clipChars, nchar(SourceUrl))
    }

    RDataDateAdded <-
        as.POSIXct(strsplit(
            as.character(RDataDateAdded), " ")[[1]][1], tz="GMT")

    lapply(c(Location_Prefix, RDataClass),
        AnnotationHubData:::.checkThatSingleStringAndNoCommas) 
    lapply(c(Genome, Species, SourceType), 
        AnnotationHubData:::.checkThatSingleStringOrNA)
    lapply(SourceVersion,
        AnnotationHubData:::.checkThatSingleStringOrNAAndNoCommas)

    new("ExperimentHubMetadata",
        ExperimentHubRoot=ExperimentHubRoot,
        HubRoot=ExperimentHubRoot,
        BiocVersion=package_version(BiocVersion),
        Coordinate_1_based=Coordinate_1_based,
        DataProvider=DataProvider,
        Description=Description,
        Genome=Genome,
        Maintainer=Maintainer,
        Notes=Notes,
        RDataClass=RDataClass,
        RDataDateAdded=as.POSIXct(RDataDateAdded),
        RDataPath=RDataPath,
        SourceUrl=SourceUrl,
        SourceVersion=SourceVersion,
        SourceType=SourceType,
        Species=Species,
        Tags=Tags,
        TaxonomyId=TaxonomyId,
        Title=Title,
        Location_Prefix=Location_Prefix,
        DispatchClass=DispatchClass,
        PreparerClass=PreparerClass,
        ## FIXME: how to determine 
        SourceSize=NA_real_,
        SourceMd5=NA_character_, 
        SourceLastModifiedDate=as.POSIXct(NA_character_), #from url in AHD
        ## NOTE: not relevant 
        Recipe=NA_character_
    )
}

## ------------------------------------------------------------------------------
## Getters and setters
## 

## TODO

## -----------------------------------------------------------------------------
## Validity 
## 

## TODO

## ------------------------------------------------------------------------------
## show 
## 

setMethod("show", "ExperimentHubMetadata",
   function(object)
{
    cat(class(object), " object: \n", sep='')
    for (slt in c("Title", "Description", "BiocVersion", "Genome",
                  "Species", "TaxonomyId", "Location_Prefix", 
                  "RDataClass", "RDataDateAdded",
                  "RDataPath", "SourceLastModifiedDate", "SourceType",
                  "SourceUrl", "SourceVersion", "Tags", "DispatchClass")) {
        value <- slot(object, slt)
        txt <- paste0(slt, ": ", paste0(as.character(value), collapse=" "))
        cat(strwrap(txt), sep="\n  ")
    }
    cat("Package: ", object@PreparerClass, '\n', sep='')
})

==> ExperimentHubData_1.4.0.tar.gz: ExperimentHubData/R/ExperimentHubMetadata-class.R <==
### =========================================================================
### ExperimentHubMetadata objects
### -------------------------------------------------------------------------
###

setClass("ExperimentHubMetadata",
    contains="HubMetadata",
    representation(
        ExperimentHubRoot="character"
    ),
    prototype = prototype(
        ExperimentHubRoot=NA_character_
    )
)

## -----------------------------------------------------------------------------
## Constructor
## 

makeExperimentHubMetadata <- function(pathToPackage, fileName=character()) 
{
    ## Differences from makeAnnotationHubMetadata:
    ## - package put in PreparerClass slot
    ## - Tags are biocViews
    stopifnot(length(fileName) <= 1)
    meta <- readMetadataFromCsv(pathToPackage, fileName=fileName)
    package <- basename(pathToPackage)
    meta$PreparerClass <- package 

    description <- read.dcf(file.path(pathToPackage, "DESCRIPTION"))
    .tags <- strsplit(gsub("\\s", "", description[,"biocViews"]), ",")[[1]]
    lapply(seq_len(nrow(meta)),
        function(x) {
            with(meta[x,], 
                 ExperimentHubMetadata(Title=Title, Description=Description, 
                                       BiocVersion=BiocVersion, Genome=Genome, 
                                       SourceType=SourceType, 
                                       SourceUrl=SourceUrl,
                                       SourceVersion=SourceVersion, 
                                       Species=Species, TaxonomyId=TaxonomyId,
                                       Coordinate_1_based=Coordinate_1_based, 
                                       DataProvider=DataProvider,
                                       Maintainer=Maintainer, 
                                       RDataClass=RDataClass, Tags=.tags, 
                                       RDataDateAdded=RDataDateAdded, 
                                       RDataPath=RDataPath, 
                                       DispatchClass=DispatchClass,
                                       PreparerClass=PreparerClass)) 
        }
    )
}

ExperimentHubMetadata <-
    function(ExperimentHubRoot=NA_character_, 
        BiocVersion=biocVersion(),
        SourceUrl=NA_character_,   ## not necessary because no downloads
        SourceType=NA_character_, 
        SourceVersion=NA_character_, 
        SourceLastModifiedDate=as.POSIXct(NA_character_), 
        SourceMd5=NA_character_, 
        SourceSize=NA_real_,
        DataProvider=NA_character_, 
        Title=NA_character_, 
        Description=NA_character_,
        Maintainer=NA_character_, 
        Species=NA_character_, 
        TaxonomyId=NA_integer_, 
        Genome=NA_character_, 
        Tags=NA_character_,
        RDataClass=NA_character_, 
        RDataDateAdded=as.POSIXct(NA_character_),
        RDataPath=NA_character_,
        Coordinate_1_based=TRUE,
        Notes=NA_character_,
        DispatchClass=NA_character_,
        PreparerClass=NA_character_,
        Location_Prefix='http://s3.amazonaws.com/experimenthub/')
{
    ## FIXME: move these checks to a general validity method
    ##        on HubMetadata that can be reused
    if (is.na(TaxonomyId)) {
        if (!is.na(Species) &&
            requireNamespace("AnnotationHubData", quietly=TRUE))
            TaxonomyId <- GenomeInfoDb:::.taxonomyId(Species)
    }
    ## FIXME: where should these coercions be handled?
    Coordinate_1_based <- as.logical(Coordinate_1_based)
    TaxonomyId <- as.integer(TaxonomyId)
    if(!(isSingleInteger(TaxonomyId) || is.na(TaxonomyId)))
        stop(paste0("ExperimentHubMetdata objects can contain",
                    " only one taxonomy ID or NA"))

    RDataDateAdded <-
        as.POSIXct(strsplit(
            as.character(RDataDateAdded), " ")[[1]][1], tz="GMT")

    lapply(c(Location_Prefix, RDataClass),
        AnnotationHubData:::.checkThatSingleStringAndNoCommas) 
    lapply(c(Genome, Species, SourceType), 
        AnnotationHubData:::.checkThatSingleStringOrNA)
    lapply(SourceVersion,
        AnnotationHubData:::.checkThatSingleStringOrNAAndNoCommas)

    new("ExperimentHubMetadata",
        ExperimentHubRoot=ExperimentHubRoot,
        HubRoot=ExperimentHubRoot,
        BiocVersion=package_version(BiocVersion),
        Coordinate_1_based=Coordinate_1_based,
        DataProvider=DataProvider,
        Description=Description,
        Genome=Genome,
        Maintainer=Maintainer,
        Notes=Notes,
        RDataClass=RDataClass,
        RDataDateAdded=as.POSIXct(RDataDateAdded),
        RDataPath=RDataPath,
        SourceUrl=SourceUrl,
        SourceVersion=SourceVersion,
        SourceType=SourceType,
        Species=Species,
        Tags=Tags,
        TaxonomyId=TaxonomyId,
        Title=Title,
        Location_Prefix=Location_Prefix,
        DispatchClass=DispatchClass,
        PreparerClass=PreparerClass,
        ## FIXME: how to determine 
        SourceSize=NA_real_,
        SourceMd5=NA_character_, 
        SourceLastModifiedDate=as.POSIXct(NA_character_), #from url in AHD
        ## NOTE: not relevant 
        Recipe=NA_character_
    )
}

## ------------------------------------------------------------------------------
## Getters and setters
## 

## TODO

## -----------------------------------------------------------------------------
## Validity 
## 

## TODO

## ------------------------------------------------------------------------------
## show 
## 

setMethod("show", "ExperimentHubMetadata",
   function(object)
{
    cat(class(object), " object: \n", sep='')
    for (slt in c("Title", "Description", "BiocVersion", "Genome",
                  "Species", "TaxonomyId", "Location_Prefix", 
                  "RDataClass", "RDataDateAdded",
                  "RDataPath", "SourceLastModifiedDate", "SourceType",
                  "SourceUrl", "SourceVersion", "Tags", "DispatchClass")) {
        value <- slot(object, slt)
        txt <- paste0(slt, ": ", paste0(as.character(value), collapse=" "))
        cat(strwrap(txt), sep="\n  ")
    }
    cat("Package: ", object@PreparerClass, '\n', sep='')
})
